<?php
//  ============================================================================
//  Copyright (c) あなたのPGM著作権表示 All rights reserved.
//  ============================================================================
require_once('config.php'); // 設定ファイル(DSN取得のため)

// DB接続
function dbConncet() {
	$db = null;
	try {
		// データベースに接続
		$db = new PDO(
			DSN,
			DSN_USERNAME,
			DSN_PASSWORD,
			[
				PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
				PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
			]
		);
	
		$res = $db->exec('SET names utf8');
		$res = $db->exec("SET time_zone = '+9:00'");
		$res = $db->exec("set autocommit = 0");
		
	} catch (PDOException $e) {
		dbErr($e);
	}
	
	return $db;
}

// エラーチェック
function dbErr($e) {
	global $db;
	// エラーが発生した場合は「500 Internal Server Error」でテキストとして表示して終了する
	echo 'The error occurred. ' . ' Errno: 500 Errortype: Internal Server Error';
	// ログ
	error_log('Date: ' . date('Y/m/d H:i:s') . "\n", 3, DIR_LOG . date('Ymd') . '_log.txt');
	error_log('Message: ' . $e->getMessage() . "\n", 3, DIR_LOG . date('Ymd') . '_log.txt');
	error_log('File: ' . $e->getFile() . "\n", 3, DIR_LOG . date('Ymd') . '_log.txt');
	error_log('Line: ' . $e->getLine() . "\n", 3, DIR_LOG . date('Ymd') . '_log.txt');
	error_log("----------\n", 3, DIR_LOG . date('Ymd') . '_log.txt');
	
	if (!empty($db)) {
		$db->rollBack();
	}
	$db = null;
	exit;
}


// PREPARE_EXECUTE処理
function dbPrepareExe($db, $sql, $values = array()) {
	try {	
		$result = array();
		$stmt = $db->prepare($sql);
		$stmt->execute($values);
		while ($row = $stmt->fetch(PDO::FETCH_ASSOC)){
			$sets = array();
			foreach($row as $key => $val) {
				$sets[$key] = $val;
			}
			$result[] = $sets;
		}
		return $result;
	} catch (PDOException $e) {
		dbErr($e);
	}
}


// PREPARE_EXECUTE_GetRow処理
function dbPrepareExeGetRow($db, $sql, $values = array()) {
	$result2 = dbPrepareExe($db, $sql, $values);
	if (count((array)$result2) > 0) {
		return $result2[0];
	} else {
		return array();
	}
	
}


// PREPARE_EXECUTE_INSERT処理
function dbPrepareExeInsert($db, $tableName, $columns) {
	try {	
		$preperes = array();
		for ($i=0; $i < count((array)$columns); $i++) {
			$preperes[] = '?';
		}
		$sql = 'INSERT INTO '.$tableName.' ('.join(', ', array_keys((array)$columns)).') VALUES ('.join(', ', $preperes).')';
		$stmt = $db->prepare($sql);
		$res = $stmt->execute(array_values((array)$columns));
		return $res;
		// if ($res == false) {
		// 	throw new PDOException("Insert $tableName Error on dbPrepareExeInsert");
		// } 
	} catch (PDOException $e) {
		dbErr($e);
	}
}

// PREPARE_EXECUTE_UPDATE処理
function dbPrepareExeUpdate($db, $tableName, $columns, $keyAry = array()) {
	try {	
		$sets = array();

		$conditions= $keyAry['sql'];
		$dataAry = array();
		foreach($columns as $key => $val) {
			$sets[] = $key . ' = ?';
			$dataAry[] = $val;
		}

		$sql = 'UPDATE '.$tableName.' SET ' .join(', ', $sets);
		if($conditions) {
			$sql .= ' WHERE ' . $conditions;
		}
		$dataAry = array_merge($dataAry, $keyAry['data']);
		$stmt = $db->prepare($sql);
		$res = $stmt->execute($dataAry);
		return $res;
	} catch (PDOException $e) {
		dbErr($e);
	}

}


// PREPARE_EXECUTE_DELETE処理
function dbPrepareExeDelete($db, $tableName, $keyAry = array()) {
	try {	
		$conditions= $keyAry['sql'];

		$sql = 'DELETE FROM ' . $tableName;
		if($conditions) {
			$sql .= ' WHERE ' . $conditions;
		}

		$stmt = $db->prepare($sql);
		$res = $stmt->execute($keyAry['data']);
		return $res;
	} catch (PDOException $e) {
		dbErr($e);
	}
}


function getDbSeq($db, $tableId, &$o) {
	global $ELEMENTS;
	
	switch($tableId) {

		case 'm_user':   // user

			if (!$db->inTransaction()) {
				$db->beginTransaction();
			}
			$sql = "lock tables m_seq write";
			$res = $db->exec($sql);
			$db->commit();

			$db->beginTransaction();
			// シーケンス　(A+yymmdd+数字) 
			$sql = "update m_seq set id = case when up_date = curdate() then (id + 1) else 1 end ,up_date =curdate() where table_id = '" . $tableId ."'";
			$res = $db->exec($sql);
			if ($res == 0) { // 新規
				$sql = "insert into m_seq values ('" . $tableId . "', curdate(), 1)";
				$res = $db->exec($sql);
				if ($res == 0) {
					throw new PDOException("insert " . $tableId . " Error on getDbSeq");
				} 
			}
			$sql = "select concat(date_format(up_date, '%Y%m%d'), substring('0000000000000000000000', 1, 4+1-length(id)), id) as seq_id from m_seq where table_id = '" . $tableId ."'";
			$stmt = $db->query($sql);
			$result = $stmt->fetch(PDO::FETCH_ASSOC);
			if ($result == false) {
				throw new PDOException("insert " . $tableId . " Error on getDbSeq");
			} 

			if (substr($result['seq_id'], 8) > (integer)substr('9999999999999999999999', 1, 4)) {
				$sql = "unlock tables";
				$res = $db->exec($sql);
				throw new PDOException("Message: " . $tableId . " u_login_id sequence over A" . substr($result['seq_id'], 0+2, 8-2) . substr('9999999999999999999999', 1, 4) ." getDbSeq() error");
			} else {
				$result['seq_id'] = 'A' . substr($result['seq_id'], 0+2, 8-2) . substr($result['seq_id'], 9, 4);
			}

			$db->commit();
			$db->beginTransaction();
			$sql = "unlock tables";
			$res = $db->exec($sql);
			$db->commit();

			break;

		case 't_corp':   // corp

			if (!$db->inTransaction()) {
				$db->beginTransaction();
			}
			$sql = "lock tables m_seq write";
			$res = $db->exec($sql);
			$db->commit();

			$db->beginTransaction();
			// シーケンス　(A+yymmdd+数字) 
			$sql = "update m_seq set id = case when up_date = curdate() then (id + 1) else 1 end ,up_date =curdate() where table_id = '" . $tableId ."'";
			$res = $db->exec($sql);
			if ($res == 0) { // 新規
				$sql = "insert into m_seq values ('" . $tableId . "', curdate(), 1)";
				$res = $db->exec($sql);
				if ($res == 0) {
					throw new PDOException("insert " . $tableId . " Error on getDbSeq");
				} 
			}
			$sql = "select concat(date_format(up_date, '%Y%m%d'), substring('0000000000000000000000', 1, 4+1-length(id)), id) as seq_id from m_seq where table_id = '" . $tableId ."'";
			$stmt = $db->query($sql);
			$result = $stmt->fetch(PDO::FETCH_ASSOC);
			if ($result == false) {
				throw new PDOException("insert " . $tableId . " Error on getDbSeq");
			} 

			if (substr($result['seq_id'], 8) > (integer)substr('9999999999999999999999', 1, 4)) {
				$sql = "unlock tables";
				$res = $db->exec($sql);
				throw new PDOException("Message: " . $tableId . " corpcd sequence over A" . substr($result['seq_id'], 0+2, 8-2) . substr('9999999999999999999999', 1, 4) ." getDbSeq() error");
			} else {
				$result['seq_id'] = 'A' . substr($result['seq_id'], 0+2, 8-2) . substr($result['seq_id'], 9, 4);
			}

			$db->commit();
			$db->beginTransaction();
			$sql = "unlock tables";
			$res = $db->exec($sql);
			$db->commit();

			break;

		case 'm_shohin':   // shohin

			if (!$db->inTransaction()) {
				$db->beginTransaction();
			}
			$sql = "lock tables m_seq write";
			$res = $db->exec($sql);
			$db->commit();

			$db->beginTransaction();
			// シーケンス　(A+yymmdd+数字) 
			$sql = "update m_seq set id = case when up_date = curdate() then (id + 1) else 1 end ,up_date =curdate() where table_id = '" . $tableId ."'";
			$res = $db->exec($sql);
			if ($res == 0) { // 新規
				$sql = "insert into m_seq values ('" . $tableId . "', curdate(), 1)";
				$res = $db->exec($sql);
				if ($res == 0) {
					throw new PDOException("insert " . $tableId . " Error on getDbSeq");
				} 
			}
			$sql = "select concat(date_format(up_date, '%Y%m%d'), substring('0000000000000000000000', 1, 3+1-length(id)), id) as seq_id from m_seq where table_id = '" . $tableId ."'";
			$stmt = $db->query($sql);
			$result = $stmt->fetch(PDO::FETCH_ASSOC);
			if ($result == false) {
				throw new PDOException("insert " . $tableId . " Error on getDbSeq");
			} 

			if (substr($result['seq_id'], 8) > (integer)substr('9999999999999999999999', 1, 3)) {
				$sql = "unlock tables";
				$res = $db->exec($sql);
				throw new PDOException("Message: " . $tableId . " products sequence over A" . substr($result['seq_id'], 0+2, 8-2) . substr('9999999999999999999999', 1, 3) ." getDbSeq() error");
			} else {
				$result['seq_id'] = 'A' . substr($result['seq_id'], 0+2, 8-2) . substr($result['seq_id'], 9, 3);
			}

			$db->commit();
			$db->beginTransaction();
			$sql = "unlock tables";
			$res = $db->exec($sql);
			$db->commit();

			break;

		case 't_item':   // item

			if (!$db->inTransaction()) {
				$db->beginTransaction();
			}
			$sql = "lock tables m_seq write";
			$res = $db->exec($sql);
			$db->commit();

			$db->beginTransaction();
			// シーケンス　(A+yymmdd+数字) 
			$sql = "update m_seq set id = case when up_date = curdate() then (id + 1) else 1 end ,up_date =curdate() where table_id = '" . $tableId ."'";
			$res = $db->exec($sql);
			if ($res == 0) { // 新規
				$sql = "insert into m_seq values ('" . $tableId . "', curdate(), 1)";
				$res = $db->exec($sql);
				if ($res == 0) {
					throw new PDOException("insert " . $tableId . " Error on getDbSeq");
				} 
			}
			$sql = "select concat(date_format(up_date, '%Y%m%d'), substring('0000000000000000000000', 1, 4+1-length(id)), id) as seq_id from m_seq where table_id = '" . $tableId ."'";
			$stmt = $db->query($sql);
			$result = $stmt->fetch(PDO::FETCH_ASSOC);
			if ($result == false) {
				throw new PDOException("insert " . $tableId . " Error on getDbSeq");
			} 

			if (substr($result['seq_id'], 8) > (integer)substr('9999999999999999999999', 1, 4)) {
				$sql = "unlock tables";
				$res = $db->exec($sql);
				throw new PDOException("Message: " . $tableId . " item01 sequence over A" . substr($result['seq_id'], 0+2, 8-2) . substr('9999999999999999999999', 1, 4) ." getDbSeq() error");
			} else {
				$result['seq_id'] = 'A' . substr($result['seq_id'], 0+2, 8-2) . substr($result['seq_id'], 9, 4);
			}

			$db->commit();
			$db->beginTransaction();
			$sql = "unlock tables";
			$res = $db->exec($sql);
			$db->commit();

			break;

		case 'm_car cr':   // car
			// シーケンス　(同一親キー内SEQ数字) 
		$conditionsDataAry[] = arryVal($o, 'corpcd');

	$sql = <<<__SQL__
select case when id is null then '1' else id + 1 end as seq_id from (
select max(id) as id FROM m_car cr 
WHERE cr.corpcd = ?
) a
__SQL__;
			$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
			if ($result['seq_id'] > (integer)substr('9999999999999999999999', 1, 20)) {
				throw new PDOException("Message: " . $tableId . " id sequence over " . substr('9999999999999999999999', 1, 20)  ." getDbSeq() error");
			}
			break;

		default:
			if ('' != $tableId) {
				if (!$db->inTransaction()) {
					$db->beginTransaction();
				}
				$sql = "lock tables m_seq write";
				$res = $db->exec($sql);
				$db->commit();

				// シーケンス
				$sql = "update m_seq set id = (id + 1)  where table_id = '" . $tableId ."'";
				$res = $db->exec($sql);
				if ($res == 0) { // 新規
					$sql = "insert into m_seq values ('" . $tableId . "', '0000/00/00 00:00:00', 1)";
					$res = $db->exec($sql);
					if ($res == 0) {
						throw new PDOException("insert " . $tableId . " Error on getDbSeq");
					} 
				}
				
				$sql = "select id as seq_id from m_seq where table_id = '" . $tableId ."'";
				$stmt = $db->query($sql);
				$result = $stmt->fetch(PDO::FETCH_ASSOC);
				if ($result == false) {
					throw new PDOException("insert " . $tableId . " Error on getDbSeq");
				} 
				$db->commit();
				$db->beginTransaction();
				$sql = "unlock tables";
				$res = $db->exec($sql);
				$db->commit();
			} else {
				throw new PDOException("Message: getDbSeq() error. tableId ignore");
			}

	}

	return $result['seq_id']; 
}




function makePassword($db, $alen = 8, $tblNm, $itemNm ) { 
	try {		
 
		$mPasswordChars = "abcdefghjkmnrstxyz2345679"; 

		$chkFlg = false;
		while ($chkFlg == false) {

			$password = ""; 
			for( $i=0; $i<$alen; $i++ ) { 
				$password .= substr( $mPasswordChars, 
					mt_rand(0, strlen($mPasswordChars)-1 ),1); 
			} 

			// パスワードがすでに使われているかをチェックする。
			$sql = <<<__SQL__
SELECT $itemNm as pwd FROM $tblNm  WHERE $itemNm = '$password'
__SQL__;

			$stmt = $db->query($sql);
			$result = $stmt->fetchAll();
			if ( empty($result)  ) {
				$chkFlg = true;
				return $password; 
			}
		}
	} catch (PDOException $e) {
		dbErr($e);
	}

} 



// seqをPKで読み込む
function seqGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'table_id');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 q.*, date_format(q.up_date, '%Y/%m/%d') AS up_date,
			date_format(q.up_date, '%Y') AS up_date_year ,
			date_format(q.up_date, '%m') AS up_date_month ,
			date_format(q.up_date, '%d') AS up_date_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_seq q 
WHERE q.table_id = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// logininfoをPKで読み込む
function logininfoGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'login_id');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 l.*, date_format(l.logininfo_insert, '%Y/%m/%d %H:%i:%s') AS logininfo_insert,
			date_format(l.logininfo_insert, '%Y') AS logininfo_insert_year ,
			date_format(l.logininfo_insert, '%m') AS logininfo_insert_month ,
			date_format(l.logininfo_insert, '%d') AS logininfo_insert_day ,
			date_format(l.logininfo_update, '%Y/%m/%d %H:%i:%s') AS logininfo_update,
			date_format(l.logininfo_update, '%Y') AS logininfo_update_year ,
			date_format(l.logininfo_update, '%m') AS logininfo_update_month ,
			date_format(l.logininfo_update, '%d') AS logininfo_update_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_logininfo l 
WHERE l.login_id = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// userをPKで読み込む
function userGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'u_login_id');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 u.*, date_format(u.u_insert, '%Y/%m/%d %H:%i:%s') AS u_insert,
			date_format(u.u_insert, '%Y') AS u_insert_year ,
			date_format(u.u_insert, '%m') AS u_insert_month ,
			date_format(u.u_insert, '%d') AS u_insert_day ,
			date_format(u.u_update, '%Y/%m/%d %H:%i:%s') AS u_update,
			date_format(u.u_update, '%Y') AS u_update_year ,
			date_format(u.u_update, '%m') AS u_update_month ,
			date_format(u.u_update, '%d') AS u_update_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_user u 
WHERE u.u_login_id = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// biztypeをPKで読み込む
function biztypeGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'biztype');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 bt.*, date_format(bt.deldt, '%Y/%m/%d %H:%i:%s') AS deldt,
			date_format(bt.deldt, '%Y') AS deldt_year ,
			date_format(bt.deldt, '%m') AS deldt_month ,
			date_format(bt.deldt, '%d') AS deldt_day ,
			date_format(bt.insdt, '%Y/%m/%d %H:%i:%s') AS insdt,
			date_format(bt.insdt, '%Y') AS insdt_year ,
			date_format(bt.insdt, '%m') AS insdt_month ,
			date_format(bt.insdt, '%d') AS insdt_day ,
			date_format(bt.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(bt.updt, '%Y') AS updt_year ,
			date_format(bt.updt, '%m') AS updt_month ,
			date_format(bt.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_biztype bt 
WHERE bt.biztype = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// corpをPKで読み込む
function corpGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'corpcd');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 co.*, date_format(co.deldt, '%Y/%m/%d %H:%i:%s') AS deldt,
			date_format(co.deldt, '%Y') AS deldt_year ,
			date_format(co.deldt, '%m') AS deldt_month ,
			date_format(co.deldt, '%d') AS deldt_day ,
			date_format(co.insdt, '%Y/%m/%d %H:%i:%s') AS insdt,
			date_format(co.insdt, '%Y') AS insdt_year ,
			date_format(co.insdt, '%m') AS insdt_month ,
			date_format(co.insdt, '%d') AS insdt_day ,
			date_format(co.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(co.updt, '%Y') AS updt_year ,
			date_format(co.updt, '%m') AS updt_month ,
			date_format(co.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM t_corp co 
WHERE co.corpcd = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// shohinをPKで読み込む
function shohinGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'products');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 sh.*, date_format(sh.insdt, '%Y/%m/%d %H:%i:%s') AS insdt,
			date_format(sh.insdt, '%Y') AS insdt_year ,
			date_format(sh.insdt, '%m') AS insdt_month ,
			date_format(sh.insdt, '%d') AS insdt_day ,
			date_format(sh.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(sh.updt, '%Y') AS updt_year ,
			date_format(sh.updt, '%m') AS updt_month ,
			date_format(sh.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_shohin sh 
WHERE sh.products = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// itemをPKで読み込む
function itemGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'item01');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 it.*, date_format(it.item10, '%Y/%m/%d') AS item10,
			date_format(it.item10, '%Y') AS item10_year ,
			date_format(it.item10, '%m') AS item10_month ,
			date_format(it.item10, '%d') AS item10_day ,
			date_format(it.item11, '%Y/%m/%d') AS item11,
			date_format(it.item11, '%Y') AS item11_year ,
			date_format(it.item11, '%m') AS item11_month ,
			date_format(it.item11, '%d') AS item11_day ,
			date_format(it.item53, '%Y/%m/%d %H:%i:%s') AS item53,
			date_format(it.item53, '%Y') AS item53_year ,
			date_format(it.item53, '%m') AS item53_month ,
			date_format(it.item53, '%d') AS item53_day ,
			date_format(it.item54, '%Y/%m/%d %H:%i:%s') AS item54,
			date_format(it.item54, '%Y') AS item54_year ,
			date_format(it.item54, '%m') AS item54_month ,
			date_format(it.item54, '%d') AS item54_day ,
			date_format(it.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(it.updt, '%Y') AS updt_year ,
			date_format(it.updt, '%m') AS updt_month ,
			date_format(it.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM t_item it 
WHERE it.item01 = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// categoryをPKで読み込む
function categoryGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'category');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 ca.*, date_format(ca.deldt, '%Y/%m/%d %H:%i:%s') AS deldt,
			date_format(ca.deldt, '%Y') AS deldt_year ,
			date_format(ca.deldt, '%m') AS deldt_month ,
			date_format(ca.deldt, '%d') AS deldt_day ,
			date_format(ca.insdt, '%Y/%m/%d %H:%i:%s') AS insdt,
			date_format(ca.insdt, '%Y') AS insdt_year ,
			date_format(ca.insdt, '%m') AS insdt_month ,
			date_format(ca.insdt, '%d') AS insdt_day ,
			date_format(ca.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(ca.updt, '%Y') AS updt_year ,
			date_format(ca.updt, '%m') AS updt_month ,
			date_format(ca.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_category ca 
WHERE ca.category = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// subcategoryをPKで読み込む
function subcategoryGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'category');
	$conditionsDataAry[] = arryVal($o, 'subcategory');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 cs.*, date_format(cs.deldt, '%Y/%m/%d %H:%i:%s') AS deldt,
			date_format(cs.deldt, '%Y') AS deldt_year ,
			date_format(cs.deldt, '%m') AS deldt_month ,
			date_format(cs.deldt, '%d') AS deldt_day ,
			date_format(cs.insdt, '%Y/%m/%d %H:%i:%s') AS insdt,
			date_format(cs.insdt, '%Y') AS insdt_year ,
			date_format(cs.insdt, '%m') AS insdt_month ,
			date_format(cs.insdt, '%d') AS insdt_day ,
			date_format(cs.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(cs.updt, '%Y') AS updt_year ,
			date_format(cs.updt, '%m') AS updt_month ,
			date_format(cs.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_subcategory cs 
WHERE cs.category = ?
 AND cs.subcategory = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// extracategoryをPKで読み込む
function extracategoryGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'category');
	$conditionsDataAry[] = arryVal($o, 'subcategory');
	$conditionsDataAry[] = arryVal($o, 'extracategory');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 ce.*, date_format(ce.deldt, '%Y/%m/%d %H:%i:%s') AS deldt,
			date_format(ce.deldt, '%Y') AS deldt_year ,
			date_format(ce.deldt, '%m') AS deldt_month ,
			date_format(ce.deldt, '%d') AS deldt_day ,
			date_format(ce.insdt, '%Y/%m/%d %H:%i:%s') AS insdt,
			date_format(ce.insdt, '%Y') AS insdt_year ,
			date_format(ce.insdt, '%m') AS insdt_month ,
			date_format(ce.insdt, '%d') AS insdt_day ,
			date_format(ce.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(ce.updt, '%Y') AS updt_year ,
			date_format(ce.updt, '%m') AS updt_month ,
			date_format(ce.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_extracategory ce 
WHERE ce.category = ?
 AND ce.subcategory = ?
 AND ce.extracategory = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}

// carをPKで読み込む
function carGetRec($db, &$o) {
	$conditionsDataAry = array();
	$conditionsDataAry[] = arryVal($o, 'corpcd');
	$conditionsDataAry[] = arryVal($o, 'id');

	$sql = <<<__SQL__
SELECT 
		-- ■--PGM<<005A>>　start--------------------------------------------
			 cr.*, date_format(cr.insdt, '%Y/%m/%d %H:%i:%s') AS insdt,
			date_format(cr.insdt, '%Y') AS insdt_year ,
			date_format(cr.insdt, '%m') AS insdt_month ,
			date_format(cr.insdt, '%d') AS insdt_day ,
			date_format(cr.updt, '%Y/%m/%d %H:%i:%s') AS updt,
			date_format(cr.updt, '%Y') AS updt_year ,
			date_format(cr.updt, '%m') AS updt_month ,
			date_format(cr.updt, '%d') AS updt_day 
		-- ■--PGM<<005A>>　end--------------------------------------------

 
FROM m_car cr 
WHERE cr.corpcd = ?
 AND cr.id = ?

__SQL__;
	$result = dbPrepareExeGetRow($db, $sql, $conditionsDataAry);
	return $result;
}



/* -------------------------------------------------- */


/* 
 * 【動作例】
 * $row['item_register_date'] = '2007-03-04';
 * 
 * →次のように置き換える
 * $row['item_register_date'] = array('y'=>'2007', 'm'=>'03', 'd'=>'04');
 */
function replaceDateArray($row) {
	foreach(array('item_show_start_ts','item_show_end_ts','item_register_date') as $name) {
		if(preg_match('!^(\d{4})\D(\d{2})\D(\d{2})!', $row[$name], $match)) {
			list($matchedFull, $y, $m, $d) = $match;
			$row[$name] = array(
				'y' => $y,
				'm' => $m,
				'd' => $d,
			);
		}
	}

	return $row;
}


?>