<?php /* 共通関数 */
//  =============================================================
//  2020 kaz PHP自動作成お助けTOOL. Start
//  修正BSDライセンス。
//  =============================================================

// htmlspecialchars 配列渡し対応版（再帰版）
function htmlspecialchars_r($vars) {
    return !is_array($vars) ? nl2br(htmlspecialchars($vars)) : array_map('htmlspecialchars_r', $vars);
}

function encloseErrorTag($errorMessages) {

    if (is_array($errorMessages)) {
        foreach((array)$errorMessages as $key => $val) {
            $errorMessages[$key] = '<div class="font-s-red-form">' . htmlspecialchars_r($val) . '</div>';
        }
    } else {
        $errorMessages = '<div class="font-s-red-form">' . nl2br(htmlspecialchars($errorMessages)) . '</div>';
    }

    return $errorMessages;
}

// 連想配列 → <input type="hidden" ...>
function makeHidden ($vars) {
    $tmp = array();

    foreach($vars as $key => $val) {
        if(!is_array($val)) { // 配列以外
            array_push($tmp, htmlHidden($key, $val));
        } else { // 配列
            array_push($tmp, __makeHidden($key, $val));
        }
    }

    return join('', $tmp);
}

// 連想配列 → <input type="hidden" ...> ヘルパー
function __makeHidden($name, $array) {
    $tmp = array();

    foreach($array as $key => $val) {
        if(!is_array($val)) {
            array_push($tmp, htmlHidden($name.'['.$key.']', $val));
        } else {
            array_push($tmp, __makeHidden($name.'['.$key.']', $val));
        }
    }

    return join('', $tmp);
}

function htmlHidden($name, $value) {
    return sprintf('<input type="hidden" name="%s" value="%s">'."\n", htmlspecialchars($name), htmlspecialchars($value));
}


// 拡張子の抽出
function extractExt($filePath, $changeCase = 'raw') {

  if(!preg_match('/\.([^\.]+)$/', $filePath, $match)) { // 「.」がみつからない
    return;
  }

  switch($changeCase) {
  case 'lower': // 小文字
    return strtolower($match[1]);
  case 'upper': // 大文字
    return strtoupper($match[1]);
  case 'raw': // そのまま
  default:
    return $match[1];
  }
}





function sendRedirect($string) {
    if(preg_match('!^https?\://!', $string)) { // 「http://」 または 「https://」 で始まる場合
        $url = $string;
    } else if(preg_match('!^/!', $string)) { // 「/」から始まる場合
        $url = (isset($_SERVER['HTTPS']) && ($_SERVER['HTTPS'] == 'on') ? 'https' : 'http') . '://' . $_SERVER['SERVER_NAME'] . $string;
    } else {
        $url = (isset($_SERVER['HTTPS']) && ($_SERVER['HTTPS'] == 'on') ? 'https' : 'http') . '://' . $_SERVER['SERVER_NAME'] . dirname($_SERVER['PHP_SELF']). '/' . $string;
    }
    header('Location: ' . $url);
}

function sendRedirectExit($string) {
    sendRedirect($string);
    exit;
}

function htmlOptions ($options, $selectedValue = null) {
    $returnHTML = '';

    foreach((array)$options as $key => $val) {
        $returnHTML .= '<option value="' . htmlspecialchars($key) . '"' . (!is_null($selectedValue) && (String)$selectedValue == (String)$key ? ' selected' : '') . '>';
        $returnHTML .= htmlspecialchars($val);
        $returnHTML .= '</option>'."\n";
    }

    return $returnHTML;
}

function checked ($needle, $haystack) {
    return (!is_null($needle) && in_array($needle, (array)$haystack)) ? ' checked' : '';
}



function makePager($option = array()) {
    $offset = $option['offset']; 
    $limit  = $option['limit'];
    $page   = $option['page'];
    $count  = $option['count'];

    // 前ページがあるか？
    $prevLink = '← 前へ';
    if($offset > 0) {
        $prevLink = '［<a href="' . $_SERVER['PHP_SELF'] . '?'. http_build_query(array('offset' => intval($offset - $limit))) . '">' . $prevLink . '</a>］';
    } else {
        $prevLink = '［' . $prevLink . '］';
    }
    
    // 次ページがあるか？
    $nextLink = '次へ →';
    if(($offset+$limit) < $count) {
        $nextLink = '［<a href="' . $_SERVER['PHP_SELF'] . '?'. http_build_query(array('offset' => intval($offset + $limit))) . '">' . $nextLink . '</a>］';
    } else {
        $nextLink =  '［' . $nextLink . '］';
    }

    return($prevLink . ' ' . $nextLink);
//    return($prevLink . ' ' . $nextLink . ' （ ' . (intval($offset / $limit) + 1).' / '.ceil($count / $limit).' ）');
}


// 指定ディレクトリから期限切れのファイルを削除する
function removeExipredFiles($targetDir, $expireDatetime) {
    $d = dir($targetDir);
    while (false !== ($entry = $d->read())) {
        $filePath = $targetDir . $entry;
        if(is_file($filePath) && filectime($filePath) < strtotime($expireDatetime)) {
            if (file_exists($filePath)) { unlink($filePath); }
        }
    }
    $d->close();
}

//マルチバイトに対応したchunk_split
function mb_chunk_split($s,$ch=76,$e="\r\n") {
    $s_ary = explode( "\r\n", $s );
    $return = '';
    foreach( $s_ary as $val ){
        $len = mb_strlen($val);
        $chunks = (int)($len/$ch);
        for($i=0;$i<=$chunks;$i++) {
            $return .= mb_substr($val,$i*$ch,$ch).$e;
        }
        //if( $chuks > 0 ){
        //    $return .= "\r\n";
        //}
    }
    return $return;
}

/* ---------- ---------- ---------- ---------- */

     /**
     * 指定したフォルダ内のファイルを削除する
     *
     */
function delFile( $path ) {
    if ( !is_dir($path) ) {
        return;
    }
    $dir = dir( $path );
    $dir->rewind();
    while($file = $dir->read()) {
        if( $file != '.' && $file != '..' && !is_dir($file) ) {
            if (file_exists( $path . $file )) { unlink( $path . $file ); }
        }
    }
    $dir->close();    
}

function exts() {
}

     /**
     * アップされた画像ファイルをリサイズする
     *
     * @access public
     * @param string $rszFilename リサイズファイル名
     * @param string $orgFilename オリジナルファイル名
     * @param String $mimeType MIMEタイプ
     * @param integer $rszWidth リサイズ後の幅
     * @param integer $rszHeight リサイズ後の高さ
     * @param integer $mod ファイルモード
     */
function saveResize($rszFilename,$orgFilename,$mimeType,$rszWidth,$rszHeight,$mod=0666) {
        if (preg_match("/jpeg/i", $mimeType)){
            $function_image_create = 'ImageCreateFromJpeg';
            $function_image_new = 'ImageJpeg';
        } elseif (preg_match("/png/i", $mimeType)) {
            $function_image_create = 'ImageCreateFromGif';
            $function_image_new = 'ImagePNG';
        } elseif (preg_match("/gif/i", $mimeType)) {
            $function_image_create = 'ImageCreateFromGif';
            $function_image_new = 'ImageGif';
        }
        
        list($orgWidth, $orgHeight) = getimagesize($orgFilename);
        
        $rcs_resize = ImageCreate($rszWidth,$rszHeight);
        $rcs_origin = @$function_image_create($orgFilename);
        
        ImageCopyResized($rcs_resize, $rcs_origin,
                        0, 0, 0, 0, 
                        $rszWidth,$rszHeight, $orgWidth,$orgHeight);
        @$function_image_new($rcs_resize, $rszFilename);
 
        ImageDestroy($rcs_origin);
        ImageDestroy($rcs_resize);
}

     /**
     * メールを送信する
     *
     * @access public
     * @param string $mailtoName 宛先名
     * @param string $mailto 宛先アドレス
     * @param string $mailfromName 差出人名
     * @param string $mailfrom 差出人アドレス
     * @param string $subject メールの件名
     * @param string $body メールの本文
     * @param string $extra その他ヘッダ
     * @param string $cSpFlg mb_chunk_splitするかしないか
     */

function mailSender( $mailtoName, $mailto, $mailfromName, $mailfrom, $subject, $body, $extra = '', $cSpFlg = true ) {
    mb_language('Japanese');
    // 元のエンコーディングを保存
    $orgEncoding = mb_internal_encoding();
    // 変換したい文字列のエンコーディングをセット
    mb_internal_encoding('UTF-8'); 
    //mb_internal_encoding('sjis'); <= UTF-8にしたので削除する
    ini_set( 'SMTP', SMTP );
    ini_set( 'smtp_port', SMTP_PORT );
    $header = '';
    
    $mailto = nl2space( $mailto );
    $mailtoName = nl2space( $mailtoName );
    $mailfrom = nl2space( $mailfrom );
    $mailfromName = nl2space( $mailfromName );
    $header .= 'return-path: '. ADMIN_RETURN_PATH ."\r\n";
//    $header .= 'To:=?Shift-Jis?B?' . base64_encode( $mailfromName ) . '=?= <' . $mailto . ">\r\n";
    if( $_ENV["OS"] == 'Windows_NT' ){
        $header .= 'From: ' . $mailfrom ."\r\n";
    } else {
        $header .= 'From: ' . mb_encode_mimeheader($mailfromName)  . ' <' . $mailfrom . ">\r\n" ;
    }
//    $subject = base64_encode( $subject );
//    $subject = "=?Shift-Jis?B?" . $subject . "=?=";
    
//    $header .= "Content-Type: text/plain; charset=ISO-2022-JP\r\n";
//    $header .= "Content-Transfer-Encoding: BASE64\r\n";
    $header .= $extra;
    $return_path = '-f '. ADMIN_RETURN_PATH;
    //$body = base64_encode( $body );
    $body = mb_convert_kana( $body , "KV" );
    if ($cSpFlg == true) {
        $body = mb_chunk_split( $body );
    }
    mb_send_mail($mailto,$subject,$body,$header,$return_path);
    // 保存しておいたエンコーディングに戻す
    mb_internal_encoding($orgEncoding); 
}

function nl2space( $src ){
    return mb_eregi_replace( "[\r\n]", ' ' , $src );
}

/* ---------- ---------- ---------- ---------- */

function makeDate($dateVars, $mode = null) {
    if(!is_array($dateVars)) { // 配列以外
        if(preg_match('!^(\d{4})\D+(\d{2})\D+(\d{2})!', $dateVars, $match)) {
            list($matchedFull, $y, $m, $d) = $match;
            return sprintf(getDateFormat($mode), $y, $m, $d);
        } else {
            return null;
        }
    } else { // 配列
        if($dateVars['y'] != '' && $dateVars['m'] != '' && $dateVars['d'] != '') {
            return sprintf(getDateFormat($mode), $dateVars['y'], $dateVars['m'], $dateVars['d']);
        } else {
            return null;
        }
    }
}

function getDateFormat($mode = null) {
    switch($mode) {
    case 'db': // DB用フォーマット
        $dateFormat = '%04d-%02d-%02d';
        break;
    case 'abbr': // 省略形
        $dateFormat = '%04d/%02d/%02d';
        break;
    default: // デフォルト
        $dateFormat = '%04d年%02d月%02d日';
    }
    return $dateFormat;
}


function stz($vars) {
    return htmlspecialchars($vars);
}

function esc($vars) {
    return is_null($vars) || $vars == '' ? "&nbsp;":nl2br(htmlspecialchars($vars));
}

function escc($vars) {
    return is_null($vars) || $vars == '' ? "&nbsp;":htmlspecialchars(number_format($vars));
}

function escd($vars) {
    return is_null($vars) || $vars == '' ? "0":htmlspecialchars(number_format($vars));
}

function escy($vars) {
    return is_null($vars) || $vars == '' ? "&nbsp;":(htmlspecialchars(number_format($vars)) . "円");
}


    /**
     * 画像をUPLOAD、DELETEする。
     * <br>
     * @param  $table       テーブル名
     * @param  $pkey        主キー情報。複数あるときは結合してください。
     * @param  $itemNames   画像のITEM名を配列で指定
     * @param  $columns     テーブルITEM内容を配列で指定
     * @param  $mode        処理区分<br>
     *                      <ul>
     *                        <li>ins_do 登録実行
     *                        <li>upd_do 更新実行
     *                        <li>del_do 削除実行
     *                      </ul>
      */
function setAndDelPhoto($table, $pkey, $itemNames, &$columns, $mode) {
    if ($mode == 'ins_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            if ( !empty($_FILES[$val]['name'])) {
                $path_parts = pathinfo( $_FILES[$val]['name'] );
                $photoNm = $val . '.' . strtolower($path_parts['extension']);
                $columns[$val] = $photoNm;
                move_uploaded_file( $_FILES[$val]['tmp_name'], $path . $photoNm );
                chmod( $path . $photoNm, 0666 );
            }
        }
    } else if ($mode == 'upd_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            $columns[$val] = arryVal($_REQUEST, 'old_' . $val);
            if ( !empty($_FILES[$val]['name']) && empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                }
                if ( !empty($_FILES[$val]['name'])) {
                    $path_parts = pathinfo( $_FILES[$val]['name'] );
                    $photoNm = $val . '.' . strtolower($path_parts['extension']);
                    $columns[$val] = $photoNm;
                    move_uploaded_file( $_FILES[$val]['tmp_name'], $path . $photoNm );
                    chmod( $path . $photoNm, 0666 );
                }
            } else if ( !empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                    $columns[$val] = '';
                }
            }
        }

    } else if ($mode == 'del_do') { 
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD .$table . '/'.  $pkey .'/';
        delFile( $path );
        if ( is_dir($path) ) {
            rmdir( $path );
        }
    }


}

    /**
     * 画像TempをUPLOADする。
     * <br>
     * @param  $itemNames   画像のITEM名を配列で指定
     * @param  $columns     テーブルITEM内容を配列で指定
      */
function setPhotoTemp($itemNames, &$columns) {
    $path = getTempFolder();
    foreach ($itemNames  as $key => $val) {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
            echo "failed itemName " . $val . " ...\n";
            exit;
        }
        if ( !empty($_FILES[$val]['name'])) {
            $path_parts = pathinfo( $_FILES[$val]['name'] );
            $photoNm = $val . '.' . strtolower($path_parts['extension']);
            $pathTmp = mb_substr($path, mb_strlen(DIR_UPLOAD_SECRET . 'temptemptemp/'), mb_strlen($path)-mb_strlen(DIR_UPLOAD_SECRET . 'temptemptemp/'));
            $_REQUEST['new_' . $val] =  $pathTmp . $photoNm ;
            move_uploaded_file( $_FILES[$val]['tmp_name'], $path . $photoNm );
        }
    }
}

    /**
     * 画像をTempからUPLOADする。
     * <br>
     * @param  $table       テーブル名
     * @param  $pkey        主キー情報。複数あるときは結合してください。
     * @param  $itemNames   画像のITEM名を配列で指定
     * @param  $columns     テーブルITEM内容を配列で指定
     * @param  $mode        処理区分<br>
     *                      <ul>
     *                        <li>ins_do 登録実行
     *                        <li>upd_do 更新実行
     *                      </ul>
      */
function setAndDelPhotoTemp($table, $pkey, $itemNames, &$columns, $mode) {
    if ($mode == 'ins_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            if ( !empty(arryVal($_REQUEST, 'new_' . $val))) {
                if(!preg_match("/^[0-9]/", arryVal($_REQUEST, 'new_' . $val)) || 
                    !(preg_match("/^[^\/]+\/[^\/]+$/", arryVal($_REQUEST, 'new_' . $val)))) { // 先頭は年なので数字のはず。/はひとつのはず。20090523追加
                    echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                    exit;
                }
                $path_parts = pathinfo( DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val) );
                $photoNm = $val . '.' . strtolower($path_parts['extension']);
                $columns[$val] = $photoNm;
                $_REQUEST[$val] = $photoNm;
                if (!copy(DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                    echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                    exit;
                }
                //if (!rename(arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                //    echo "failed to rename " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                //}
                // tempフォルダはtempフォルダを作成する前に消しています。（1日以前のものを対象にして）
                chmod( $path . $photoNm, 0666 );
            }
        }
    } else if ($mode == 'upd_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            $columns[$val] = arryVal($_REQUEST, 'old_' . $val);
            $_REQUEST[$val] = arryVal($_REQUEST, 'old_' . $val);
            if ( !empty(arryVal($_REQUEST, 'new_' . $val)) && empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                }
                if ( !empty(arryVal($_REQUEST, 'new_' . $val))) {
                    if(!preg_match("/^[0-9]/", arryVal($_REQUEST, 'new_' . $val)) || 
                        !(preg_match("/^[^\/]+\/[^\/]+$/", arryVal($_REQUEST, 'new_' . $val)))) { // 先頭は年なので数字のはず。/はひとつのはず。20090523追加
                        echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                        exit;
                    }
                    $path_parts = pathinfo( DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val) );
                    $photoNm = $val . '.' . strtolower($path_parts['extension']);
                    $columns[$val] = $photoNm;
                    $_REQUEST[$val] = $photoNm;
                    if (!copy(DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                        echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                        exit;
                    }
                    //if (!rename(arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                    //    echo "failed to rename " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                    //}
                    // tempフォルダはtempフォルダを作成する前に消しています。（1日以前のものを対象にして）
                    chmod( $path . $photoNm, 0666 );
                }
            } else if ( !empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                    $columns[$val] = '';
                    $_REQUEST[$val] = '';
                }
            }
        }

    }
}

function getTempFolder() {
    // テンポラリ使用フォルダを作成する
    $path = DIR_UPLOAD_SECRET . 'temptemptemp/';
    if ( !is_dir($path) ) {
        mkdir( $path, 0777 );
    } else {
        // 一日以上過ぎたテンポラリフォルダを削除する。
        removeOldTempFolder($path, date("YmdHis",getDay(-1)));
    }

    $i = 0;
    $loopflg = true;
    while ($loopflg == true) {
        //$temptime = date('YmdHis') . $i++;
        $temptime = date('YmdHis') . '_' . uniqid();
        $path = DIR_UPLOAD_SECRET . 'temptemptemp/' . $temptime . '/';
        if ( !is_dir($path) ) { // パスがないとき作る
            $loopflg = false;
            mkdir( $path, 0777 );
        }
    }
    return $path;
}

function delTempFolder($path) {
    delFile( $path );
    rmdir( $path );
}

// 一日以上過ぎたテンポラリフォルダを削除する。
function removeOldTempFolder($dir, $dateYmdHis) {
    if ( is_dir($dir) ) {
        if ($handle = opendir("$dir")) {
            while (false !== ($item = readdir($handle))) {
                if ($item != "." && $item != "..") {
                    if (is_dir("$dir/$item")) {
                        if (strlen($item) > 14 && substr($item, 0, 14) < $dateYmdHis) {
                            removeOldTempFolder("$dir/$item", $dateYmdHis);
                        }
                    } else {
                        if (file_exists("$dir/$item")) { unlink("$dir/$item"); }
                        //echo " removing $dir/$item<br>\n";
                    }
                }
            }
            closedir($handle);
            $path_parts = pathinfo($dir);
            if (strlen($path_parts['basename']) > 14 && substr($path_parts['basename'], 0, 14) < $dateYmdHis) {
                rmdir($dir);
                //echo "removing $dir<br>\n";
            }
        }
    }
}

// ＋－日timeを求める
function getDay($day){
    $now = time();
    return mktime(date("H",$now),date("i",$now),date("s",$now),date("m",$now),date("d",$now)+$day,date("Y",$now));
}


function wtTempFile($path, $contents, $filename) {
    if (!($fd = @fopen($path . $filename, 'wb'))) {
        echo("not problem writing temporary file " . $path . $filename);
        exit;
    }
    fwrite($fd, $contents);
    fclose($fd);
    chmod( $path . $filename, 0666 );

}

function mkTempZipAndLoad($path, $zipName, $files="*.*") {
    exec("zip -j " . $path . '/' . $zipName . '  ' .$path . '/' . $files);

    $handle = fopen($path . '/' . $zipName, "rb");
    $ziplen = filesize($path . '/' . $zipName);
    $contents = fread($handle, filesize($path . '/' . $zipName));
    fclose($handle);

    header("Content-Disposition: attachment; filename=moushikomiA.zip");
    header("Content-Type: application/octet-stream");
    header("Cache-Control: public");
    header("Pragma: public");
    header('Content-Length: ' . $ziplen);
    print $contents;


}


    /**
     * 画像を秘密フォルダにUPLOAD、DELETEする。
     * <br>
     * @param  $table       テーブル名
     * @param  $pkey        主キー情報。複数あるときは結合してください。
     * @param  $itemNames   画像のITEM名を配列で指定
     * @param  $columns     テーブルITEM内容を配列で指定
     * @param  $mode        処理区分<br>
     *                      <ul>
     *                        <li>ins_do 登録実行
     *                        <li>upd_do 更新実行
     *                        <li>del_do 削除実行
     *                      </ul>
      */
function setAndDelPhotoSecret($table, $pkey, $itemNames, &$columns, $mode) {
    if ($mode == 'ins_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD_SECRET .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD_SECRET .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            if ( !empty($_FILES[$val]['name'])) {
                $path_parts = pathinfo( $_FILES[$val]['name'] );
                $photoNm = $val . '.' . strtolower($path_parts['extension']);
                $columns[$val] = $photoNm;
                move_uploaded_file( $_FILES[$val]['tmp_name'], $path . $photoNm );
                chmod( $path . $photoNm, 0666 );
            }
        }
    } else if ($mode == 'upd_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD_SECRET .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD_SECRET .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            $columns[$val] = arryVal($_REQUEST, 'old_' . $val);
            if ( !empty($_FILES[$val]['name']) && empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                }
                if ( !empty($_FILES[$val]['name'])) {
                    $path_parts = pathinfo( $_FILES[$val]['name'] );
                    $photoNm = $val . '.' . strtolower($path_parts['extension']);
                    $columns[$val] = $photoNm;
                    move_uploaded_file( $_FILES[$val]['tmp_name'], $path . $photoNm );
                    chmod( $path . $photoNm, 0666 );
                }
            } else if ( !empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                    $columns[$val] = '';
                }
            }
        }

    } else if ($mode == 'del_do') { 
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD_SECRET .$table . '/'.  $pkey .'/';
        delFile( $path );
        if ( is_dir($path) ) {
            rmdir( $path );
        }
    }


}


    /**
     * 画像をTempから秘密フォルダにUPLOADする。
     * <br>
     * @param  $table       テーブル名
     * @param  $pkey        主キー情報。複数あるときは結合してください。
     * @param  $itemNames   画像のITEM名を配列で指定
     * @param  $columns     テーブルITEM内容を配列で指定
     * @param  $mode        処理区分<br>
     *                      <ul>
     *                        <li>ins_do 登録実行
     *                        <li>upd_do 更新実行
     *                      </ul>
      */
function setAndDelPhotoTempSecret($table, $pkey, $itemNames, &$columns, $mode) {
    if ($mode == 'ins_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD_SECRET .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD_SECRET .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            if ( !empty(arryVal($_REQUEST, 'new_' . $val))) {
                if(!preg_match("/^[0-9]/", arryVal($_REQUEST, 'new_' . $val)) || 
                    !(preg_match("/^[^\/]+\/[^\/]+$/", arryVal($_REQUEST, 'new_' . $val)))) { // 先頭は年なので数字のはず。/はひとつのはず。20090523追加
                    echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                    exit;
                }
                $path_parts = pathinfo( DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val) );
                $photoNm = $val . '.' . strtolower($path_parts['extension']);
                $columns[$val] = $photoNm;
                $_REQUEST[$val] = $photoNm;
                if (!copy(DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                    echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                    exit;
                }
                //if (!rename(arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                //    echo "failed to rename " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                //}
                // tempフォルダはtempフォルダを作成する前に消しています。（1日以前のものを対象にして）
                chmod( $path . $photoNm, 0666 );
            }
        }
    } else if ($mode == 'upd_do') {
        if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $table) || 
          !preg_match("/^[0-9a-zA-Z_\-]+$/", $pkey)) { // TABLE名キーであること。20090523追加
            echo "failed tableName = " . $table . "failed tableKey = " . $pkey . " ...\n";
            exit;
        }
        $path = DIR_UPLOAD_SECRET .$table . '/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );
        $path = DIR_UPLOAD_SECRET .$table . '/'.  $pkey .'/';
        if ( !is_dir($path) ) mkdir( $path, 0777 );

        foreach ($itemNames  as $key => $val) {
            if (!preg_match("/^[0-9a-zA-Z_\-]+$/", $val)) { // ITEM名であること。20090523追加
                echo "failed itemName " . $val . " ...\n";
                exit;
            }
            $columns[$val] = arryVal($_REQUEST, 'old_' . $val);
            $_REQUEST[$val] = arryVal($_REQUEST, 'old_' . $val);
            if ( !empty(arryVal($_REQUEST, 'new_' . $val)) && empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                }
                if ( !empty(arryVal($_REQUEST, 'new_' . $val))) {
                    if(!preg_match("/^[0-9]/", arryVal($_REQUEST, 'new_' . $val)) || 
                        !(preg_match("/^[^\/]+\/[^\/]+$/", arryVal($_REQUEST, 'new_' . $val)))) { // 先頭は年なので数字のはず。/はひとつのはず。20090523追加
                        echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                        exit;
                    }
                    $path_parts = pathinfo( DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val) );
                    $photoNm = $val . '.' . strtolower($path_parts['extension']);
                    $columns[$val] = $photoNm;
                    $_REQUEST[$val] = $photoNm;
                    if (!copy(DIR_UPLOAD_SECRET . 'temptemptemp/' . arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                        echo "failed to copy " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                        exit;
                    }
                    //if (!rename(arryVal($_REQUEST, 'new_' . $val), $path . $photoNm)) {
                    //    echo "failed to rename " . arryVal($_REQUEST, 'new_' . $val) . " ...\n";
                    //}
                    // tempフォルダはtempフォルダを作成する前に消しています。（1日以前のものを対象にして）
                    chmod( $path . $photoNm, 0666 );
                }
            } else if ( !empty( arryVal($_REQUEST, 'del_' . $val) )) {
                if (arryVal($_REQUEST, 'old_' . $val) != '') {
                    if (!preg_match("/^[0-9a-zA-Z_\-]+\.[0-9a-zA-Z_\-]+$/", arryVal($_REQUEST, 'old_' . $val))) { // ファイル名であること。20090523追加
                        echo "failed to del " . arryVal($_REQUEST, 'old_' . $val) . " ...\n";
                        exit;
                    }
                    if (file_exists($path . arryVal($_REQUEST, 'old_' . $val))) { unlink($path . arryVal($_REQUEST, 'old_' . $val)); }
                    $columns[$val] = '';
                    $_REQUEST[$val] = '';
                }
            }
        }

    }
}

// DB Item Name　編集
function editDbItemName($vars) {
    return preg_replace('/[^a-z0-9_$#]+/i', '', $vars);
}

/**
 *　大中小分類が一つになったELEMENTSをDBデータから作成する。
 *　中分類、小分類を省略できます。
 *  よって、大分類のみ、大分類＋中分類、大分類＋中分類＋小分類の3種類に対応できます。
 * 　結果：
 * 　　＄ELEMENTSに直接設定します。
 *     エレメントの内容は「function.php」の「creLrgMidSmlCategoryEleBase()」メソッド参照。
 *  パラメータ：
 * @param  $elementNm     ：ELEMENTS名称
 *   大分類：省略不可
 * @param  $lrgTblNm      ：大分類テーブル名
 * @param  $lrgTblAriasNm ：大分類テーブルのエイリアス名
 * @param  $lrgKey1Item   ：大分類テーブルの大分類キー項目名
 * @param  $lrgNmItem     ：大分類テーブルの大分類日本語項目名
 * @param  $lrgEngNmItem  ：大分類テーブルの大分類英語項目名（大分類英語項目名がない場合null）
 * @param  $lrgDelItem    ：大分類テーブルの削除日項目名（削除日項目がない場合null）
 *   中分類：省略可
 * @param  $midTblNm      ：中分類テーブル名
 * @param  $midTblAriasNm ：中分類テーブルのエイリアス名
 * @param  $midKey1Item   ：中分類テーブルの大分類キー項目名
 * @param  $midKey2Item   ：中分類テーブルの中分類キー項目名
 * @param  $midNmItem     ：中分類テーブルの中分類日本語項目名
 * @param  $midEngNmItem  ：中分類テーブルの中分類英語項目名（中分類英語項目名がない場合null）
 * @param  $midDelItem    ：中分類テーブルの削除日項目名（削除日項目がない場合null）
 *   小分類：省略可
 * @param  $smlTblNm      ：小分類テーブル名
 * @param  $smlTblAriasNm ：小分類テーブルのエイリアス名
 * @param  $smlKey1Item   ：小分類テーブルの大分類キー項目名
 * @param  $smlKey2Item   ：小分類テーブルの中分類キー項目名
 * @param  $smlKey3Item   ：小分類テーブルの小分類キー項目名
 * @param  $smlNmItem     ：小分類テーブルの小分類日本語項目名
 * @param  $smlEngNmItem  ：小分類テーブルの小分類英語項目名（小分類英語項目名がない場合null）
 * @param  $smlDelItem    ：小分類テーブルの削除日項目名（削除日項目がない場合null）
  */
// 
 
function creLrgMidSmlCategoryEle($elementNm, 
    $lrgTblNm, $lrgTblAriasNm, $lrgKey1Item, $lrgNmItem, $lrgEngNmItem, $lrgDelItem,
    $midTblNm=null, $midTblAriasNm=null, $midKey1Item=null, $midKey2Item=null, $midNmItem=null, $midEngNmItem=null, $midDelItem=null,
    $smlTblNm=null, $smlTblAriasNm=null, $smlKey1Item=null, $smlKey2Item=null, $smlKey3Item=null, $smlNmItem=null, $smlEngNmItem=null, $smlDelItem=null) {
    global $ELEMENTS;

    $ary = & creLrgMidSmlCategoryEleBase('all', '', '', '',
    $elementNm, 
    $lrgTblNm, $lrgTblAriasNm, $lrgKey1Item, $lrgNmItem, $lrgEngNmItem, $lrgDelItem,
    $midTblNm, $midTblAriasNm, $midKey1Item, $midKey2Item, $midNmItem, $midEngNmItem, $midDelItem,
    $smlTblNm, $smlTblAriasNm, $smlKey1Item, $smlKey2Item, $smlKey3Item, $smlNmItem, $smlEngNmItem, $smlDelItem);
    $ELEMENTS[$elementNm] = & $ary[$elementNm];
}

/**
 *　大中小分類が一つになったELEMENTSをDBデータから作成する。
 *　中分類、小分類を省略できます。
 *  よって、大分類のみ、大分類＋中分類、大分類＋中分類＋小分類の3種類に対応できます。
 *  $lrgMidSmlAllKbn='all'の場合、大中小分類のELEMENTSを戻す。。
 *  $lrgMidSmlAllKbn='lrg'、'mid'、'sml'の場合、該当分類のエレメント配列を戻す。
 *  　　　　　　　　　　　　　　　　　　　　　該当以外の分類は空配列。
 *  　　　　　　　　　例:'mid'の場合mid'はエレメント配列、'lrg'と'sml'は空配列。
 *　
 *  結果：
 *     $lrgMidSmlAllKbn='all'の場合、大中小分類ELEMENTSを戻す。
 *     $lrgMidSmlAllKbn='lrg'、'mid'、'sml'の場合、作成した該当分類のエレメントを戻す。
 *  　　　　　　　　　　　　　　　　　　　　　　該当以外の分類は空配列。
 *  　　　　　　　　　　例:'mid'の場合'lrg'と'sml'は空配列。
 *
 *  パラメータ：
 * @param  $lrgMidSmlAllKbn：'all'、'lrg'、'mid'、'sml'
 * @param  $lrgKey        ：大分類キー　指定しない場合''を設定
 * @param  $midKey        ：中分類キー　指定しない場合''を設定
 * @param  $smlKey        ：小分類キー　指定しない場合''を設定
 *  パラメータ：
 * @param  $elementNm     ：ELEMENTS名称
 *   大分類：省略不可
 * @param  $lrgTblNm      ：大分類テーブル名
 * @param  $lrgTblAriasNm ：大分類テーブルのエイリアス名
 * @param  $lrgKey1Item   ：大分類テーブルの大分類キー項目名
 * @param  $lrgNmItem     ：大分類テーブルの大分類日本語項目名
 * @param  $lrgEngNmItem  ：大分類テーブルの大分類英語項目名（大分類英語項目名がない場合null）
 * @param  $lrgDelItem    ：大分類テーブルの削除日項目名（削除日項目がない場合null）
 *   中分類：省略可
 * @param  $midTblNm      ：中分類テーブル名
 * @param  $midTblAriasNm ：中分類テーブルのエイリアス名
 * @param  $midKey1Item   ：中分類テーブルの大分類キー項目名
 * @param  $midKey2Item   ：中分類テーブルの中分類キー項目名
 * @param  $midNmItem     ：中分類テーブルの中分類日本語項目名
 * @param  $midEngNmItem  ：中分類テーブルの中分類英語項目名（中分類英語項目名がない場合null）
 * @param  $midDelItem    ：中分類テーブルの削除日項目名（削除日項目がない場合null）
 *   小分類：省略可
 * @param  $smlTblNm      ：小分類テーブル名
 * @param  $smlTblAriasNm ：小分類テーブルのエイリアス名
 * @param  $smlKey1Item   ：小分類テーブルの大分類キー項目名
 * @param  $smlKey2Item   ：小分類テーブルの中分類キー項目名
 * @param  $smlKey3Item   ：小分類テーブルの小分類キー項目名
 * @param  $smlNmItem     ：小分類テーブルの小分類日本語項目名
 * @param  $smlEngNmItem  ：小分類テーブルの小分類英語項目名（小分類英語項目名がない場合null）
 * @param  $smlDelItem    ：小分類テーブルの削除日項目名（削除日項目がない場合null）
 * 
 * -----$lrgMidSmlAllKbn='lrg'の場合の例-----
 * 作成例： 単独項目（大中小の分類がない）の場合。
 *          以下はキー指定なしで$lrgMidSmlAllKbn='lrg'の場合の例。
 *          大分類キー指定の場合は対応するデータのみ作成される。
 * Array ( [ary_category] => Array ( 
 *     [lrg] => Array ( 
 *         [A] => Array ( [0] => 食品 [1] => shokuhin [2] =>  ) 
 *         [B] => Array ( [0] => 衣類 [1] => irui [2] =>  ) )
 *     [mid] => Array () 
 *     [sml] => Array () )
 *
 * -----$lrgMidSmlAllKbn='mid'の場合の例-----
 * 作成例： 大分類、中分類がある場合。
 *          以下はキー指定なしで$lrgMidSmlAllKbn='mid'の場合の例。
 *          大分類キー、中分類キー指定の場合は対応するデータのみ作成される。
 * Array ( [ary_category] => Array ( 
 *     [lrg] => Array () 
 *     [mid] => Array ( 
 *         [A] => Array ( [1] => Array ( [0] => 野菜 [1] => yasai [2] =>  ) 
 *                        [2] => Array ( [0] => 果物 [1] => kudamono [2] =>  ) 
 *                        [3] => Array ( [0] => 肉 [1] => niku [2] =>  ) ) 
 *         [B] => Array ( [1] => Array ( [0] => セーター [1] => seta [2] =>  ) 
 *                        [2] => Array ( [0] => Ｔシャツ [1] => tsyayu [2] =>  ) ) )
 *     [sml] => Array () )
 * 
 * -----$lrgMidSmlAllKbn='sml'の場合の例-----
 * 作成例： 大分類、中分類、小分類がある場合。
 *          以下はキー指定なしで$lrgMidSmlAllKbn='sml'の場合の例。
 *          大分類キー、中分類キー、小分類キー指定の場合は対応するデータのみ作成される。
 * Array ( [ary_category] => Array ( 
 *     [lrg] => Array () 
 *     [lrg] => Array () 
 *     [sml] => Array ( 
 *         [A] => Array ( [1] => Array ( [a] => Array ( [0] => キャベツ [1] => kyabetu [2] =>  ) 
 *                                       [b] => Array ( [0] => ピーマン [1] => pman [2] =>  ) ) 
 *                        [2] => Array ( [a] => Array ( [0] => リンゴ [1] => ringo [2] =>  ) 
 *                                       [b] => Array ( [0] => バナナ [1] => banana [2] =>  ) ) 
 *                        [3] => Array ( [a] => Array ( [0] => 牛 [1] => gyu [2] =>  ) 
 *                                       [b] => Array ( [0] => 豚 [1] => buta [2] =>  ) 
 *                                       [c] => Array ( [0] => 鶏 [1] => niwatoeri [2] =>  ) ) ) 
 *         [B] => Array ( [1] => Array ( [a] => Array ( [0] => 長袖 [1] => nagasode [2] =>  ) 
 *                                       [b] => Array ( [0] => 半袖 [1] => hansode [2] =>  ) ) 
 *                                       [c] => Array ( [0] => 7分袖 [1] => 7busode [2] => del ) ) 
 *                        [2] => Array ( [a] => Array ( [0] => 長袖 [1] => nagasode [2] =>  ) 
 *                                       [b] => Array ( [0] => 半袖 [1] => hansode [2] =>  ) ) ) ) ) ) 
 * 
//  * -----$lrgMidSmlAllKbn='all'の場合の例-----
//  * 作成例： 単独項目（大中小の分類がない）の場合。
//  *          以下はキー指定なしで$lrgMidSmlAllKbn='all'の場合の例。
//  *          大分類キー指定の場合は対応するデータのみ作成される。
//  * Array ( [ary_category] => Array ( 
//  *     [lrg] => Array ( 
//  *         [A] => Array ( [0] => 食品 [1] => shokuhin [2] =>  ) 
//  *         [B] => Array ( [0] => 衣類 [1] => irui [2] =>  ) ) )
//  * 
//  * 作成例： 大分類、中分類がある場合。
//  *          以下はキー指定なしで$lrgMidSmlAllKbn='all'の場合の例。
//  *          大分類キー、中分類キー指定の場合は対応するデータのみ作成される。
//  * Array ( [ary_category] => Array ( 
//  *     [lrg] => Array ( 
//  *         [A] => Array ( [0] => 食品 [1] => shokuhin [2] =>  ) 
//  *         [B] => Array ( [0] => 衣類 [1] => irui [2] =>  ) ) 
//  *     [mid] => Array ( 
//  *         [A] => Array ( [1] => Array ( [0] => 野菜 [1] => yasai [2] =>  ) 
//  *                        [2] => Array ( [0] => 果物 [1] => kudamono [2] =>  ) 
//  *                        [3] => Array ( [0] => 肉 [1] => niku [2] =>  ) ) 
//  *         [B] => Array ( [1] => Array ( [0] => セーター [1] => seta [2] =>  ) 
//  *                        [2] => Array ( [0] => Ｔシャツ [1] => tsyayu [2] =>  ) ) ) )
//  * 
//  * 作成例： 大分類、中分類、小分類がある場合。
//  *          以下はキー指定なしで$lrgMidSmlAllKbn='all'の場合の例。
//  *          大分類キー、中分類キー、小分類キー指定の場合は対応するデータのみ作成される。
//  * Array ( [ary_category] => Array ( 
//  *     [lrg] => Array ( 
//  *         [A] => Array ( [0] => 食品 [1] => shokuhin [2] =>  ) 
//  *         [B] => Array ( [0] => 衣類 [1] => irui [2] =>  ) ) 
//  *     [mid] => Array ( 
//  *         [A] => Array ( [1] => Array ( [0] => 野菜 [1] => yasai [2] =>  ) 
//  *                        [2] => Array ( [0] => 果物 [1] => kudamono [2] =>  ) 
//  *                        [3] => Array ( [0] => 肉 [1] => niku [2] =>  ) ) 
//  *         [B] => Array ( [1] => Array ( [0] => セーター [1] => seta [2] =>  ) 
//  *                        [2] => Array ( [0] => Ｔシャツ [1] => tsyayu [2] =>  ) ) ) 
//  *     [sml] => Array ( 
//  *         [A] => Array ( [1] => Array ( [a] => Array ( [0] => キャベツ [1] => kyabetu [2] =>  ) 
//  *                                       [b] => Array ( [0] => ピーマン [1] => pman [2] =>  ) ) 
//  *                        [2] => Array ( [a] => Array ( [0] => リンゴ [1] => ringo [2] =>  ) 
//  *                                       [b] => Array ( [0] => バナナ [1] => banana [2] =>  ) ) 
//  *                        [3] => Array ( [a] => Array ( [0] => 牛 [1] => gyu [2] =>  ) 
//  *                                       [b] => Array ( [0] => 豚 [1] => buta [2] =>  ) 
//  *                                       [c] => Array ( [0] => 鶏 [1] => niwatoeri [2] =>  ) ) ) 
//  *         [B] => Array ( [1] => Array ( [a] => Array ( [0] => 長袖 [1] => nagasode [2] =>  ) 
//  *                                       [b] => Array ( [0] => 半袖 [1] => hansode [2] =>  ) ) 
//  *                                       [c] => Array ( [0] => 7分袖 [1] => 7busode [2] => del ) ) 
//  *                        [2] => Array ( [a] => Array ( [0] => 長袖 [1] => nagasode [2] =>  ) 
//  *                                       [b] => Array ( [0] => 半袖 [1] => hansode [2] =>  ) ) ) ) ) ) 
  */
// 
 
function creLrgMidSmlCategoryEleBase(
    $lrgMidSmlAllKbn, $lrgKey, $midKey, $smlKey,
    $elementNm, 
    $lrgTblNm, $lrgTblAriasNm, $lrgKey1Item, $lrgNmItem, $lrgEngNmItem, $lrgDelItem,
    $midTblNm=null, $midTblAriasNm=null, $midKey1Item=null, $midKey2Item=null, $midNmItem=null, $midEngNmItem=null, $midDelItem=null,
    $smlTblNm=null, $smlTblAriasNm=null, $smlKey1Item=null, $smlKey2Item=null, $smlKey3Item=null, $smlNmItem=null, $smlEngNmItem=null, $smlDelItem=null) {

    global $db;

	try {		
        $elem = array();
        // if ($lrgMidSmlAllKbn == 'all') { // ＄ELEMENTSに直接設定します。
            // $elem[$elementNm] = array();
            // $elem[$elementNm]['lrg'] = array(); // 大分類を作る。
            // if ($midTblNm != null) { // 中分類指定があるとき中分類を作る。
            //     $elem[$elementNm]['mid'] = array();
            //     if ($smlTblNm != null) { // 小分類指定があるとき小分類を作る。
            //         $elem[$elementNm]['sml'] = array();
            //     }
            // }
        // } else { // 新規array()を戻します。
            $elem[$elementNm] = array();
            $elem[$elementNm]['lrg'] = array(); // 大分類を作る。
            $elem[$elementNm]['mid'] = array(); // 中分類を作る。
            $elem[$elementNm]['sml'] = array(); // 小分類を作る。
        // }

        // 大分類
        $sql1 = 
        "SELECT $lrgTblAriasNm.$lrgKey1Item, ";
        if ($lrgNmItem != null && $lrgNmItem != "") {
            $sql1 = $sql1 . " $lrgTblAriasNm.$lrgNmItem as lrgnm,";
        } else {
            $sql1 = $sql1 . " '' as lrgnm,";
        }
        if ($lrgEngNmItem != null && $lrgEngNmItem != "") {
            $sql1 = $sql1 . " $lrgTblAriasNm.$lrgEngNmItem as lrgengnm";
        } else {
            $sql1 = $sql1 . " '' as lrgengnm";
        }
        if ($lrgDelItem != null && $lrgDelItem != "") {
            $sql1 = $sql1 . ",  case when ($lrgTblAriasNm.$lrgDelItem IS NULL OR  $lrgTblAriasNm.$lrgDelItem = '0000/00/00 00:00:00') then '' else 'del' end as delkbn ";
        } else {
            $sql1 = $sql1 . ",  '' as delkbn ";
        }
        $sql1 = $sql1 . " FROM $lrgTblNm $lrgTblAriasNm ";
        $conditions= array();
        if ($lrgKey != '') {
            $sql1 = $sql1 . " WHERE $lrgTblAriasNm.$lrgKey1Item = ? "; // 完全一致
            $conditions[] = $lrgKey;
        }
        $sql1 = $sql1 . " ORDER BY  $lrgTblAriasNm.$lrgKey1Item ";
        $result1 = dbPrepareExe($db, $sql1, $conditions);

        foreach ( $result1 as $vals1 ){
            if ($lrgMidSmlAllKbn == 'lrg' || $lrgMidSmlAllKbn == 'all') {
                $elem[$elementNm]['lrg'][$vals1[$lrgKey1Item]] = 
                    array($vals1['lrgnm'], $vals1['lrgengnm'], $vals1['delkbn']);
            }
                
            if ($lrgKey != '' && ($lrgMidSmlAllKbn == 'mid' || $lrgMidSmlAllKbn == 'sml' || $lrgMidSmlAllKbn == 'all')) {
                // if ($midTblNm != null) { // 中分類指定があるとき中分類を作る。
                //     if ($lrgMidSmlAllKbn == 'mid' || $lrgMidSmlAllKbn == 'all') {
                //         $elem[$elementNm]['mid'][$vals1[$lrgKey1Item]] = array();
                //     }
                //     if ($lrgMidSmlAllKbn == 'sml' || $lrgMidSmlAllKbn == 'all') {
                //         if ($smlTblNm != null) { // 小分類指定があるとき小分類を作る。
                //             $elem[$elementNm]['sml'][$vals1[$lrgKey1Item]] = array();
                //         }
                //     }
                // }


                if ($midTblNm != null) { // 中分類指定があるとき中分類を作る。
                    // 中分類
                    $lrgKey2 = $vals1[$lrgKey1Item];
                    $sql2 = 
                    "SELECT $midTblAriasNm.$midKey1Item, $midTblAriasNm.$midKey2Item, ";
                    if ($midNmItem != null && $midNmItem != "") {
                        $sql2 = $sql2 . " $midTblAriasNm.$midNmItem as midnm,";
                    } else {
                        $sql2 = $sql2 . " ''  as midnm,";
                    }
                    if ($midEngNmItem != null && $midEngNmItem != "") {
                        $sql2 = $sql2 . " $midTblAriasNm.$midEngNmItem as midengnm";
                    } else {
                        $sql2 = $sql2 . " '' as midengnm";
                    }
                    if ($midDelItem != null && $midDelItem != "") {
                        $sql2 = $sql2 . ",  case when ($midTblAriasNm.$midDelItem IS NULL OR $midTblAriasNm.$midDelItem = '0000/00/00 00:00:00') then '' else 'del' end as delkbn ";
                    } else {
                        $sql2 = $sql2 . ",  '' as delkbn ";
                    }
                    $sql2 = $sql2 ." FROM $midTblNm $midTblAriasNm ";
                    $conditions= array();
                    $sql2 = $sql2 . " WHERE $midTblAriasNm.$midKey1Item = ? ";
                    $conditions[] = $lrgKey2;
                    if ($midKey != '') {
                        $sql2 = $sql2 . " and $midTblAriasNm.$midKey2Item = ? "; // 完全一致
                        $conditions[] = $midKey;
                    }
                    $sql2 = $sql2 . " ORDER BY $midTblAriasNm.$midKey1Item, $midTblAriasNm.$midKey2Item ";
                    $result2 = dbPrepareExe($db, $sql2, $conditions);
               
                    foreach( $result2 as $vals2 ){
                        if ($lrgMidSmlAllKbn == 'mid' || $lrgMidSmlAllKbn == 'all') {
                            $elem[$elementNm]['mid'][$vals2[$midKey1Item]][$vals2[$midKey2Item]] = 
                                array($vals2['midnm'], $vals2['midengnm'], $vals2['delkbn']);
                        }
                        if ($midKey != '' && ($lrgMidSmlAllKbn == 'sml' || $lrgMidSmlAllKbn == 'all')) {
                            if ($smlTblNm != null) { // 小分類指定があるとき小分類を作る。
                                $elem[$elementNm]['sml'][$vals2[$midKey1Item]][$vals2[$midKey2Item]] = array();

                                // 小分類
                                $midKey2 = $vals2[$midKey2Item];
                                $sql3 = 
                                "SELECT $smlTblAriasNm.$smlKey1Item, $smlTblAriasNm.$smlKey2Item, $smlTblAriasNm.$smlKey3Item,";
                                if ($smlNmItem != null && $smlNmItem != "") {
                                    $sql3 = $sql3 . " $smlTblAriasNm.$smlNmItem as smlnm,";
                                } else {
                                    $sql3 = $sql3 . " '' as smlnm,";
                                }
                                if ($smlEngNmItem != null && $smlEngNmItem != "") {
                                    $sql3 = $sql3 . " $smlTblAriasNm.$smlEngNmItem as smlengnm";
                                } else {
                                    $sql3 = $sql3 . " '' as smlengnm";
                                }
                                if ($smlDelItem != null && $smlDelItem != "") {
                                    $sql3 = $sql3 . ",  case when ($smlTblAriasNm.$smlDelItem IS NULL OR $smlTblAriasNm.$smlDelItem = '0000/00/00 00:00:00') then '' else 'del' end as delkbn ";
                                } else {
                                    $sql3 = $sql3 . ",  '' as delkbn ";
                                }
                                $sql3 = $sql3 . " FROM $smlTblNm $smlTblAriasNm ";
                                $conditions= array();
                                $sql3 = $sql3 . " WHERE  $smlTblAriasNm.$smlKey1Item = ? " .
                                        "      AND $smlTblAriasNm.$smlKey2Item = ? ";
                                $conditions[] = $lrgKey2;
                                $conditions[] = $midKey2;
                                if ($smlKey != '') {
                                    $sql3 = $sql3 . " AND $smlTblAriasNm.$smlKey3Item = ? "; // 完全一致
                                    $conditions[] = $smlKey;
                                }
                                $sql3 = $sql3 . " ORDER BY $smlTblAriasNm.$smlKey1Item, $smlTblAriasNm.$smlKey2Item, $smlTblAriasNm.$smlKey3Item ";
                                $result3 = dbPrepareExe($db, $sql3, $conditions);
                
                                foreach( $result3 as $vals3 ){
                                    $elem[$elementNm]['sml'][$vals3[$smlKey1Item]][$vals3[$smlKey2Item]][$vals3[$smlKey3Item]] = 
                                        array($vals3['smlnm'], $vals3['smlengnm'], $vals3['delkbn']);
                                }
                            }
                        }
                    }
                }
            }
        }
        return $elem;
	} catch (PDOException $e) {
		dbErr($e);
	}
}

// デバックLOG
function outDebugLog($msg = PHP_EOL) {
    $log = '';
    $typ = gettype($msg);
    if ($typ == 'string') {         // stringはそのまま出力
        $log .= $msg . ' ';
    } else if ($typ == 'double') {     // doubleはそのまま出力
        $log .= $msg . ' ';
    } else if ($typ == 'boolean') { // booleanはtrue、false出力
        $log .= $msg ? 'true' : 'false' . ' ';
    } else {                         // その他はvar_dumpまたはprint_rして出力
        // var_dumpより print_rのほうが見やすいので。（print_r($msg, true);はob_start関連がいらない。）
        $dmp = print_r($msg, true);
        $log .= $dmp;
    }
    // PHPファイル名とライン行を求める
    $backtrace = debug_backtrace();
    $prg = '';
    foreach($backtrace as $key => $vals ){
        $phpname = preg_match('/[_a-zA-Z0-9\.]+\.[^\.]+$/',  $vals["file"], $match) ? $match[0] : $vals["file"];
        $prg .= $phpname. " line=" .$vals["line"] . ' ';
        break; // 最初の１件だけにしておく
    }
    $log =  $prg . ': ' .$log;
    // DEBUGログ出力
    error_log('Date: ' . date('Y/m/d H:i:s') . "\n", 3, DIR_LOG . date('Ymd') . '_debugLog.txt');
	error_log('Message: ' . $log . "\n, 3, DIR_LOG . date('Ymd') . '_debugLog.txt'");
	error_log("----------\n", 3, DIR_LOG . date('Ymd') . '_debugLog.txt');

	// $fp = fopen(DIR_LOG . date('Ymd') . '_debugLog.txt', 'a');
	// flock($fp, LOCK_EX);
	// fwrite($fp, 'Date: ' . date('Y/m/d H:i:s') . "\n");
	// fwrite($fp, 'Message: ' . $log . "\n");
	// fwrite($fp, "----------\n");
	// flock($fp, LOCK_UN);
	// fclose($fp);
}

/**
 * Ajaxによるリクエストかどうか
 *
 * @return boolean True or False
 */
function isAjax()
{
    if(isset($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest'){
        return true;
    }
    return false;
}

//  =============================================================
//  2020 kaz PHP自動作成お助けTOOL.End
//  修正BSDライセンス。
//  =============================================================

//  ================================================================================================
//  http://ter.ath.cx/yusei/yuseiki/PHP+fgetcsv%28%29%E3%81%AF%E4%BD%BF%E3%81%86%E3%81%AA Start
//  「NYSL Version 0.9982」ライセンス。
//  ================================================================================================
function fgetExcelCSV(&$fp , $length = null, $delimiter = ',' , $enclosure = '"') {
    $line = fgets($fp);
    if($line === false) {
        return false;
    }
    $bytes = preg_split('//' , trim($line));
    array_shift($bytes);array_pop($bytes);
    $cols = array();
    $col = '';
    $isInQuote = false;
    while($bytes) {
        $byte = array_shift($bytes);
        if($isInQuote) {
            if($byte == $enclosure) {
                if($bytes[0] == $enclosure) {
                    $col .= $byte;
                    array_shift($bytes);
                } else {
                    $isInQuote = false;
                }
            } else {
                $col .= $byte;
            }
        } else {
            if($byte == $delimiter) {
                $cols[] = $col;
                $col = '';
            } elseif($byte == $enclosure && $col == '') {
                $isInQuote = true;
            } else {
                $col .= $byte;
            }
        }
        while(!$bytes && $isInQuote) {
            $col .= "\n";
            $line = fgets($fp);
            if($line === false) {
                $isInQuote = false;
            } else {
                $bytes = preg_split('//' , trim($line));
                array_shift($bytes);array_pop($bytes);
            }
        }
    }
    $cols[] = $col;
    return $cols;
}

//  ================================================================================================
//  http://ter.ath.cx/yusei/yuseiki/PHP+fgetcsv%28%29%E3%81%AF%E4%BD%BF%E3%81%86%E3%81%AA End
//  「NYSL Version 0.9982」ライセンス。
//  ================================================================================================

// 配列値取得
function arryVal ($vars, $itemName) {
    return $vars[$itemName] ?? "";
}

?>